==> qtjambi-xml-6.2.9-sources.jar: io/qt/xml/QDomEntityReference.java <==
package io.qt.xml;


/**
 * <p>Represents an XML entity reference</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qdomentityreference.html">QDomEntityReference</a></p>
 */
public class QDomEntityReference extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomentityreference.html#QDomEntityReference">QDomEntityReference::QDomEntityReference()</a></p>
     */
    public QDomEntityReference(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomEntityReference instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomentityreference.html#QDomEntityReference-1">QDomEntityReference::QDomEntityReference(QDomEntityReference)</a></p>
     */
    public QDomEntityReference(io.qt.xml.QDomEntityReference x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomEntityReference instance, io.qt.xml.QDomEntityReference x);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDomEntityReference(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QDomEntityReference clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QDomEntityReference clone_native(long __this_nativeId);
}

==> qtjambi-xml-6.5.0-sources.jar: io/qt/xml/QDomEntityReference.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>Represents an XML entity reference</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qdomentityreference.html">QDomEntityReference</a></p>
 */
public class QDomEntityReference extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomentityreference.html#QDomEntityReference">QDomEntityReference::QDomEntityReference()</a></p>
     */
    public QDomEntityReference(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomEntityReference instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomentityreference.html#QDomEntityReference-1">QDomEntityReference::QDomEntityReference(QDomEntityReference)</a></p>
     */
    public QDomEntityReference(io.qt.xml.@NonNull QDomEntityReference x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomEntityReference instance, io.qt.xml.QDomEntityReference x);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomentityreference.html#operator-eq">QDomEntityReference::operator=(QDomEntityReference)</a></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomEntityReference arg__1){
        assign_native_cref_QDomEntityReference(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomEntityReference(long __this__nativeId, long arg__1);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QDomEntityReference(QPrivateConstructor p) { super(p); } 
    
    
    @QtUninvokable
    @Override
    public QDomEntityReference clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomEntityReference clone_native(long __this_nativeId);
}
